==> amarok-1.83.tar.bz2: amarok-1.83/src/dynamic/RandomPlaylist.h <==
/***************************************************************************
 * copyright            : (C) 2008 Daniel Jones <danielcjones@gmail.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/


#ifndef AMAROK_RANDOMPLAYLIST_H
#define AMAROK_RANDOMPLAYLIST_H

#include "DynamicPlaylist.h"
#include "Meta.h"

class Collection;
class QueryMaker;

namespace Dynamic {

    /**
     * A temporary random mode; it will be replaced by a biased playlist when it's
     * ready
     */
    class RandomPlaylist : public DynamicPlaylist
    {
        public:
            RandomPlaylist();
            RandomPlaylist( Collection* );
            ~RandomPlaylist();

            Meta::TrackPtr  getTrack();

        private:
            void fillCache();
            static const int CACHE_SIZE = 100;
            Meta::TrackList m_cache;
    };
}

#endif

==> amarok-1.86.tar.bz2: amarok-1.86/src/dynamic/RandomPlaylist.h <==
/***************************************************************************
 * copyright            : (C) 2008 Daniel Jones <danielcjones@gmail.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/


#ifndef AMAROK_RANDOMPLAYLIST_H
#define AMAROK_RANDOMPLAYLIST_H

#include "DynamicPlaylist.h"
#include "Meta.h"

class Collection;
class QueryMaker;

namespace Dynamic {

    /**
     * A temporary random mode; it will be replaced by a biased playlist when it's
     * ready
     */
    class RandomPlaylist : public DynamicPlaylist
    {
        public:
            RandomPlaylist();
            RandomPlaylist( Collection* );
            ~RandomPlaylist();

            Meta::TrackPtr  getTrack();

        private:
            void fillCache();
            static const int CACHE_SIZE;
            Meta::TrackList m_cache;
    };
}

#endif
